effectiveDLng abstract method

double effectiveDLng(
  1. LatLng p1,
  2. LatLng p2
)

Returns the effective longitudinal delta in radians that the distance formula should use.

Values in (−pi, pi] are treated as the short arc. Values outside that range (absolute value > pi) are treated as the long arc by both Haversine and Vincenty.

Implementation

double effectiveDLng(LatLng p1, LatLng p2);